calc_ess_bound: Calculate Minimum Required Effective Sample Size...

View source: R/utils.R

calc_ess_boundR Documentation

Calculate Minimum Required Effective Sample Size (M_alpha_eps_p)

Description

Computes the theoretical minimum effective sample size required to obtain a confidence region with relative volume epsilon and coverage 1 - alpha, based on Vats, Flegal and Jones (2019) and Vats and Knudson (2021).

Usage

calc_ess_bound(p = 1, alpha = 0.05, epsilon = 0.1)

Arguments

p

Integer, number of parameters.

alpha

Numeric, significance level (default 0.05 for 95% confidence).

epsilon

Numeric, relative volume tolerance (default 0.10).

Value

Numeric scalar, required minimum ESS.

Examples

calc_ess_bound(p = 1, alpha = 0.05, epsilon = 0.10)
calc_ess_bound(p = 5, alpha = 0.05, epsilon = 0.05)

LugsailGR documentation built on Aug. 5, 2026, 9:08 a.m.