| calc_lugsail_bm | R Documentation |
Computes the replicated lugsail batch means variance estimator (univariate) or time-average covariance matrix (multivariate) for MCMC chains as described by Vats and Knudson (2021).
calc_lugsail_bm(arr, b = NULL)
arr |
3D numeric array of dimension |
b |
Batch size. If |
A list containing:
tau_L |
Scalar variance estimate if |
b |
Batch size used. |
a |
Number of batches. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.