| calc_ess_bound | R Documentation |
Computes the theoretical minimum effective sample size required to obtain a
confidence region with relative volume epsilon and coverage 1 - alpha,
based on Vats, Flegal and Jones (2019) and Vats and Knudson (2021).
calc_ess_bound(p = 1, alpha = 0.05, epsilon = 0.1)
p |
Integer, number of parameters. |
alpha |
Numeric, significance level (default 0.05 for 95% confidence). |
epsilon |
Numeric, relative volume tolerance (default 0.10). |
Numeric scalar, required minimum ESS.
calc_ess_bound(p = 1, alpha = 0.05, epsilon = 0.10)
calc_ess_bound(p = 5, alpha = 0.05, epsilon = 0.05)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.